BleConnectorError

Enum BleConnectorError 

pub enum BleConnectorError {
    Unknown,
}
Available on crate features ble and unstable only.
Error type for the BLE connector.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



Unknown

Unknown BLE error occurred.